@@ -1,5 +1,5 @@
 from collections import OrderedDict
-from typing import Dict, Set, Type
+from typing import Dict, Set, Type, List
 
 from oaas.client_definition import ClientDefinition
 from oaas.client_provider import ClientMiddleware
@@ -7,7 +7,7 @@ from oaas.server_provider import ServerMiddleware
 from oaas.service_definition import ServiceDefinition
 
 clients: Dict[Type, ClientDefinition] = OrderedDict()
-services: Dict[ServiceDefinition, bool] = OrderedDict()
+services: List[ServiceDefinition] = []
 
 servers_middleware: Set[ServerMiddleware] = set()
 clients_middleware: Set[ClientMiddleware] = set()
