@@ -1,6 +1,8 @@
 import abc
 from typing import TypeVar
 
+from oaas.service_definition import ServiceDefinition
+
 T = TypeVar("T")
 
 
@@ -17,3 +19,7 @@ class ServerMiddleware(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def join(self) -> None:
         ...
+
+    @abc.abstractmethod
+    def can_serve(self, service: ServiceDefinition) -> bool:
+        ...
